<?php
/**
 * Manager class.
 *
 * This class handles loading the customize register actions for the extension.
 *
 * @package   Rootstrap\Customize
 * @author    Sky Shabatura
 * @copyright Copyright (c) 2019, Sky Shabatura
 * @link      https://github.com/skyshab/rootstrap
 * @license   http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */

namespace Rootstrap\Customize;

use Rootstrap\Abstracts\Bootable;


/**
 * Creates a new Rootstrap_Custom_Sections object.
 *
 * @since  1.0.0
 * @access public
 */
class Manager extends Bootable {


    /**
     * Stores Directory Path
     *
     * @since 1.0.0
     * @var array
     */
    private $dir;

    /**
     * Stores Resources Path
     *
     * @since 1.0.0
     * @var array
     */
    private $resources;


    /**
     * Load resources.
     *
     * @since 1.0.0
     * @return object
     */
    public function boot() {

        // get the vendor path and create a reference to this package's resource directory
        $vendor = apply_filters( 'rootstrap/resources/vendor', false );
        if ( !$vendor ) return;
        $this->resources = $vendor . '/skyshab/rootstrap-customize/resources';
        $this->dir = __DIR__;

        add_action( 'customize_register', [ $this, 'panels' ] );
        add_action( 'customize_register', [ $this, 'tabs' ], PHP_INT_MAX );
        add_action( 'customize_register', [ $this, 'sequences' ], PHP_INT_MAX );
        add_action( 'customize_controls_enqueue_scripts', [ $this, 'customize_resources' ] );
    }


    /**
     * Load Rootstrap Custom Panels
     *
     * @since 1.0.0
     * @return void
     */
    public function panels($manager) {

        // The file that contains our custom panels class
        require_once $this->dir . '/Controls/class-rootstrap-custom-panel.php';

        // Register the custom panel
        $manager->register_panel_type( 'Rootstrap_Custom_Panel' );
    }


    /**
     * Create tabs
     *
     * @since 1.0.0
     * @return void
     */
    public function tabs($manager) {

        // The file that contains our customizer control for tabs.
        require_once $this->dir . '/Controls/class-tabs-control.php';

        // Create Tabs
        $tabs = apply_filters( 'rootstrap/tabs', [] );
        foreach( $tabs as $args ) {
            $new_tab = new Tabs($manager, $args);
        }
    }


    /**
     * Create sequences
     *
     * @since 1.0.0
     * @return void
     */
    public function sequences($manager) {

        // The file that contains our customizer control for sequences.
        require_once $this->dir . '/Controls/class-sequence-control.php';

        // Create Sequences
        $sequences = apply_filters( 'rootstrap/sequences', [] );
        foreach( $sequences as $args ) {
            $new_sequence = new Sequence($manager, $args);
        }
    }


    /**
     * Enqueue scripts and styles.
     *
     *  If filters are applied defining file locations, load scripts and styles.
     *
     * @since 1.0.0
     */
    public function customize_resources() {
        wp_enqueue_script( 'rootstrap-custom-panels', $this->resources . '/js/custom-panels.min.js', ['customize-controls', 'jquery'], null, true );
        wp_enqueue_script( 'rootstrap-customize-customize-controls', $this->resources . '/js/customize-controls.min.js', ['customize-controls'], null, true );
        wp_enqueue_style( 'rootstrap-customize-customize-controls', $this->resources . '/css/customize-controls.min.css' );
    }

}
